==> dustrac_2.0.1.orig.tar.gz: DustRacing2D-2.0.1/src/editor/translations/dustrac-editor_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE" sourcelanguage="en">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About Dust Racing</source>
        <translation>Über Dust Racing</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&apos;</source>
        <translation>&apos;</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Wiederholen</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Leeren</translation>
    </message>
    <message>
        <source>A new track &apos;%1&apos; created. Columns: %2, Rows: %3.</source>
        <translation>Eine neue Strecke namens »%1« erstellt. Spalten: %2; Zeilen: %3.</translation>
    </message>
    <message>
        <source>Set route: not a valid track.</source>
        <translation>Route setzen: Keine gültige Strecke.</translation>
    </message>
    <message>
        <source>Setting the route defines checkpoints for the cars so
that no shortcuts can be taken. It also defines
driving lines for the computer players.

Click on the tiles one by one and make a closed loop
with the target nodes. You can adjust the nodes afterwads.
Start from the first tile after the finish line tile
to make the lap detection and timing work correctly.
Click on the first node again to finish.</source>
        <translation>Das Setzen der Route definiert die Kontrollpunkte, damit keine Abkürzungen genommen werden können. Es definiert auch die Fahrtlinien für die Computerspieler.

Klicken Sie nacheinander auf die entsprechenden Kacheln und erstellen Sie einen geschlossenen Rundkurs mit den Zielknoten. Sie können auch nachher die Knoten anpassen. Beginnen Sie mit der ersten Kachel hinter der Ziellinienkachel, um die Rundenerkennung und die Zeitmessung korrekt einzurichten. Klicken Sie erneut auf dem ersten Knoten zum Fertigstellen.</translation>
    </message>
    <message>
        <source>Track &apos;%1&apos; opened.</source>
        <translation>Stecke »%1« geöffnet.</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <source>&amp;Route</source>
        <translation>&amp;Route</translation>
    </message>
    <message>
        <source>Erase object</source>
        <translation>Objekt löschen</translation>
    </message>
    <message>
        <source>Index set to &apos;%1&apos;.</source>
        <translation type="vanished">Index auf »%1« gesetzt.</translation>
    </message>
    <message>
        <source>Choose &apos;File -&gt; New&apos; or &apos;File -&gt; Open&apos; to start.</source>
        <translation>Wählen Sie »Datei → Neu« oder »Datei → Öffnen«, um anzufangen.</translation>
    </message>
    <message>
        <source>Set route, checkpoints and driving lines.</source>
        <translation>Route, Kontrollpunkte und Fahrtlinien setzen.</translation>
    </message>
    <message>
        <source>Enlarge ver size</source>
        <translation>Vertikal vergrößern</translation>
    </message>
    <message>
        <source>Randomly rotate objects</source>
        <translation>Objekte zufällig rotieren</translation>
    </message>
    <message>
        <source>Scale:</source>
        <translation>Anzeigegröße:</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <source>Scale set to %1%</source>
        <translation>Anzeigegröße auf %1% gesetzt</translation>
    </message>
    <message>
        <source>Open a track</source>
        <translation>Eine Strecke öffnen</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Öffnen …</translation>
    </message>
    <message>
        <source>Set route</source>
        <translation>Route setzen</translation>
    </message>
    <message>
        <source>Clear &amp;route</source>
        <translation>&amp;Route leeren</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Über &amp;Qt</translation>
    </message>
    <message>
        <source>ERROR!!: Cannot load objects from &apos;</source>
        <translation>Fehler! Objekte können nicht geladen werden von: &apos;</translation>
    </message>
    <message>
        <source>Save a track</source>
        <translation>Eine Strecke speichern</translation>
    </message>
    <message>
        <source>&amp;Save as...</source>
        <translation>Speichern &amp;unter …</translation>
    </message>
    <message>
        <source>&apos; saved.</source>
        <translation>&apos; gespeichert.</translation>
    </message>
    <message>
        <source>Loading &apos;%1&apos;..</source>
        <translation>Lade: %1 …</translation>
    </message>
    <message>
        <source>ERROR!!: %1 doesn&apos;t exist.</source>
        <translation>Fehler! %1 existiert nicht.</translation>
    </message>
    <message>
        <source>Save your work to correct location.</source>
        <translation>Speichern Sie Ihre Arbeit an einem gültigem Ort ab.</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Über Qt</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <source>&amp;Clear all</source>
        <translation type="vanished">Alles &amp;leeren</translation>
    </message>
    <message>
        <source>Track &apos;</source>
        <translation>Stecke &apos;</translation>
    </message>
    <message>
        <source>&amp;Set route..</source>
        <translation>Route &amp;setzen …</translation>
    </message>
    <message>
        <source>New file</source>
        <translation>Neue Datei</translation>
    </message>
    <message>
        <source>Track Files (*.trk)</source>
        <translation>Steckendateien (*.trk)</translation>
    </message>
    <message>
        <source>Invalid track. Route cannot be set.</source>
        <translation>Ungültige Strecke. Route kann nicht gesetzt werden.</translation>
    </message>
    <message>
        <source>Failed to open track &apos;</source>
        <translation>Stecke konnte nicht geöffnet werden: &apos;</translation>
    </message>
    <message>
        <source>Failed to save track as &apos;</source>
        <translation>Strecke konnte nicht gespeichert werden als: &apos;</translation>
    </message>
    <message>
        <source>To make the game find your circuits, save them to %1%2%3%2</source>
        <translation>Damit das Spiel Ihre Strecken findet, speichern Sie sie ab unter: %1%2%3%2</translation>
    </message>
    <message>
        <source>Failed to save track &apos;</source>
        <translation>Strecke konnte nicht gespeichert werden: &apos;</translation>
    </message>
    <message>
        <source>Enlarge hor size</source>
        <translation>Horizontal vergrößern</translation>
    </message>
    <message>
        <source>&amp;Set properties..</source>
        <translation>&amp;Eigenschaften setzen …</translation>
    </message>
    <message>
        <source>Set route: route finished.</source>
        <translation>Route setzen: Route fertiggestellt.</translation>
    </message>
    <message>
        <source>Set route: begin.</source>
        <translation>Route setzen: Angefangen.</translation>
    </message>
    <message>
        <source>Track properties updated.</source>
        <translation>Streckeneigenschaften aktualisiert</translation>
    </message>
</context>
<context>
    <name>NewTrackDialog</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Number of tile columns:</source>
        <translation>Anzahl der Kachelspalten:</translation>
    </message>
    <message>
        <source>Create a new track</source>
        <translation>Eine neue Strecke erstellen</translation>
    </message>
    <message>
        <source>Track name:</source>
        <translation>Streckenname:</translation>
    </message>
    <message>
        <source>Number of tile rows:</source>
        <translation>Anzahl der Kachelzeilen:</translation>
    </message>
    <message>
        <source>User track:</source>
        <translation>Benutzerstrecke:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Tiles cleared.</source>
        <translation type="vanished">Kacheln geleert.</translation>
    </message>
    <message>
        <source>Route cleared.</source>
        <translation>Route geleert.</translation>
    </message>
</context>
<context>
    <name>QWidget</name>
    <message>
        <source> CW..</source>
        <translation> im Uhrzeigersinn</translation>
    </message>
    <message>
        <source> CCW..</source>
        <translation> entgegen dem Uhrzeigersinn</translation>
    </message>
    <message>
        <source>Set computer hint &apos;brake hard&apos;..</source>
        <translation>Computertipp auf »Vollbremsung« setzen</translation>
    </message>
    <message>
        <source>Rotate..</source>
        <translation>Rotieren …</translation>
    </message>
    <message>
        <source>Set size..</source>
        <translation>Größe setzen …</translation>
    </message>
    <message>
        <source>Clear computer hint</source>
        <translation>Computertipp entfernen</translation>
    </message>
    <message>
        <source>Rotate 90</source>
        <translation>Rotieren um 90</translation>
    </message>
    <message>
        <source>Set computer hint &apos;brake&apos;..</source>
        <translation>Computertipp auf »Bremsen« setzen</translation>
    </message>
    <message>
        <source>Insert row..</source>
        <translation type="vanished">Zeile einfügen</translation>
    </message>
    <message>
        <source>Delete row..</source>
        <translation>Zeile löschen</translation>
    </message>
    <message>
        <source>Insert column..</source>
        <translation type="vanished">Spalte einfügen</translation>
    </message>
    <message>
        <source>Delete column..</source>
        <translation>Spalte löschen</translation>
    </message>
    <message>
        <source>Exclude from minimap</source>
        <translation>Aus der Minikarte ausschließen</translation>
    </message>
    <message>
        <source>Insert row before..</source>
        <translation>Zeile vorher einfügen</translation>
    </message>
    <message>
        <source>Insert row after..</source>
        <translation>Zeile danach einfügen</translation>
    </message>
    <message>
        <source>Insert column before..</source>
        <translation>Spalte vorher einfügen</translation>
    </message>
    <message>
        <source>Insert column after..</source>
        <translation>Spalte nach einfügen</translation>
    </message>
    <message>
        <source>Force stationary</source>
        <translation>Machen Sie stationär</translation>
    </message>
</context>
<context>
    <name>RotateDialog</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Angle in degrees:</source>
        <translation>Winkel in Grad:</translation>
    </message>
    <message>
        <source>Rotate Object</source>
        <translation>Objekt rotieren</translation>
    </message>
</context>
<context>
    <name>TargetNodeSizeDlg</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Breite:</translation>
    </message>
    <message>
        <source>Set target node size</source>
        <translation>Zielknotengröße setzen</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Höhe:</translation>
    </message>
</context>
<context>
    <name>TrackPropertiesDialog</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Set track properties</source>
        <translation>Streckeneigenschaften setzen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Index:</source>
        <translation>Index:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation></translation>
    </message>
    <message>
        <source>User track:</source>
        <translation>Benutzerstrecke:</translation>
    </message>
</context>
</TS>

==> dustrac_2.0.5.orig.tar.gz: DustRacing2D-2.0.5/src/editor/translations/dustrac-editor_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE" sourcelanguage="en">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About Dust Racing</source>
        <translation>Über Dust Racing</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&apos;</source>
        <translation>&apos;</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Wiederholen</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Bearbeiten</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Leeren</translation>
    </message>
    <message>
        <source>A new track &apos;%1&apos; created. Columns: %2, Rows: %3.</source>
        <translation>Eine neue Strecke namens »%1« erstellt. Spalten: %2; Zeilen: %3.</translation>
    </message>
    <message>
        <source>Set route: not a valid track.</source>
        <translation>Route setzen: Keine gültige Strecke.</translation>
    </message>
    <message>
        <source>Setting the route defines checkpoints for the cars so
that no shortcuts can be taken. It also defines
driving lines for the computer players.

Click on the tiles one by one and make a closed loop
with the target nodes. You can adjust the nodes afterwads.
Start from the first tile after the finish line tile
to make the lap detection and timing work correctly.
Click on the first node again to finish.</source>
        <translation>Das Setzen der Route definiert die Kontrollpunkte, damit keine Abkürzungen genommen werden können. Es definiert auch die Fahrtlinien für die Computerspieler.

Klicken Sie nacheinander auf die entsprechenden Kacheln und erstellen Sie einen geschlossenen Rundkurs mit den Zielknoten. Sie können auch nachher die Knoten anpassen. Beginnen Sie mit der ersten Kachel hinter der Ziellinienkachel, um die Rundenerkennung und die Zeitmessung korrekt einzurichten. Klicken Sie erneut auf dem ersten Knoten zum Fertigstellen.</translation>
    </message>
    <message>
        <source>Track &apos;%1&apos; opened.</source>
        <translation>Stecke »%1« geöffnet.</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <source>&amp;Route</source>
        <translation>&amp;Route</translation>
    </message>
    <message>
        <source>Erase object</source>
        <translation>Objekt löschen</translation>
    </message>
    <message>
        <source>Index set to &apos;%1&apos;.</source>
        <translation type="vanished">Index auf »%1« gesetzt.</translation>
    </message>
    <message>
        <source>Choose &apos;File -&gt; New&apos; or &apos;File -&gt; Open&apos; to start.</source>
        <translation>Wählen Sie »Datei → Neu« oder »Datei → Öffnen«, um anzufangen.</translation>
    </message>
    <message>
        <source>Set route, checkpoints and driving lines.</source>
        <translation>Route, Kontrollpunkte und Fahrtlinien setzen.</translation>
    </message>
    <message>
        <source>Enlarge ver size</source>
        <translation type="vanished">Vertikal vergrößern</translation>
    </message>
    <message>
        <source>Randomly rotate objects</source>
        <translation>Objekte zufällig rotieren</translation>
    </message>
    <message>
        <source>Scale:</source>
        <translation>Anzeigegröße:</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Auswählen</translation>
    </message>
    <message>
        <source>Scale set to %1%</source>
        <translation>Anzeigegröße auf %1% gesetzt</translation>
    </message>
    <message>
        <source>Open a track</source>
        <translation>Eine Strecke öffnen</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Öffnen …</translation>
    </message>
    <message>
        <source>Set route</source>
        <translation>Route setzen</translation>
    </message>
    <message>
        <source>Clear &amp;route</source>
        <translation>&amp;Route leeren</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Über &amp;Qt</translation>
    </message>
    <message>
        <source>ERROR!!: Cannot load objects from &apos;</source>
        <translation>FEHLER! Objekte können nicht geladen werden von: &apos;</translation>
    </message>
    <message>
        <source>Save a track</source>
        <translation>Eine Strecke speichern</translation>
    </message>
    <message>
        <source>&amp;Save as...</source>
        <translation>Speichern &amp;unter …</translation>
    </message>
    <message>
        <source>&apos; saved.</source>
        <translation>&apos; gespeichert.</translation>
    </message>
    <message>
        <source>Loading &apos;%1&apos;..</source>
        <translation>Lade: %1 …</translation>
    </message>
    <message>
        <source>ERROR!!: %1 doesn&apos;t exist.</source>
        <translation>FEHLER! %1 existiert nicht.</translation>
    </message>
    <message>
        <source>Save your work to correct location.</source>
        <translation>Speichern Sie Ihre Arbeit an einem gültigem Ort ab.</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Über Qt</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Neu</translation>
    </message>
    <message>
        <source>&amp;Clear all</source>
        <translation type="vanished">Alles &amp;leeren</translation>
    </message>
    <message>
        <source>Track &apos;</source>
        <translation>Stecke &apos;</translation>
    </message>
    <message>
        <source>&amp;Set route..</source>
        <translation>Route &amp;setzen …</translation>
    </message>
    <message>
        <source>New file</source>
        <translation>Neue Datei</translation>
    </message>
    <message>
        <source>Track Files (*.trk)</source>
        <translation>Steckendateien (*.trk)</translation>
    </message>
    <message>
        <source>Invalid track. Route cannot be set.</source>
        <translation>Ungültige Strecke. Route kann nicht gesetzt werden.</translation>
    </message>
    <message>
        <source>Failed to open track &apos;</source>
        <translation>Stecke konnte nicht geöffnet werden: &apos;</translation>
    </message>
    <message>
        <source>Failed to save track as &apos;</source>
        <translation>Strecke konnte nicht gespeichert werden als: &apos;</translation>
    </message>
    <message>
        <source>To make the game find your circuits, save them to %1%2%3%2</source>
        <translation>Damit das Spiel Ihre Strecken findet, speichern Sie sie ab unter: %1%2%3%2</translation>
    </message>
    <message>
        <source>Failed to save track &apos;</source>
        <translation>Strecke konnte nicht gespeichert werden: &apos;</translation>
    </message>
    <message>
        <source>Enlarge hor size</source>
        <translation type="vanished">Horizontal vergrößern</translation>
    </message>
    <message>
        <source>&amp;Set properties..</source>
        <translation>&amp;Eigenschaften setzen …</translation>
    </message>
    <message>
        <source>Set route: route finished.</source>
        <translation>Route setzen: Route fertiggestellt.</translation>
    </message>
    <message>
        <source>Set route: begin.</source>
        <translation>Route setzen: Angefangen.</translation>
    </message>
    <message>
        <source>Track properties updated.</source>
        <translation>Streckeneigenschaften aktualisiert</translation>
    </message>
    <message>
        <source>, %4%2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewTrackDialog</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Number of tile columns:</source>
        <translation>Anzahl der Kachelspalten:</translation>
    </message>
    <message>
        <source>Create a new track</source>
        <translation>Eine neue Strecke erstellen</translation>
    </message>
    <message>
        <source>Track name:</source>
        <translation>Streckenname:</translation>
    </message>
    <message>
        <source>Number of tile rows:</source>
        <translation>Anzahl der Kachelzeilen:</translation>
    </message>
    <message>
        <source>User track:</source>
        <translation>Benutzerstrecke:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Tiles cleared.</source>
        <translation type="vanished">Kacheln geleert.</translation>
    </message>
    <message>
        <source>Route cleared.</source>
        <translation>Route geleert.</translation>
    </message>
</context>
<context>
    <name>QWidget</name>
    <message>
        <source> CW..</source>
        <translation> im Uhrzeigersinn</translation>
    </message>
    <message>
        <source> CCW..</source>
        <translation> entgegen dem Uhrzeigersinn</translation>
    </message>
    <message>
        <source>Set computer hint &apos;brake hard&apos;..</source>
        <translation>Computertipp auf »Vollbremsung« setzen</translation>
    </message>
    <message>
        <source>Rotate..</source>
        <translation>Rotieren …</translation>
    </message>
    <message>
        <source>Set size..</source>
        <translation>Größe setzen …</translation>
    </message>
    <message>
        <source>Clear computer hint</source>
        <translation>Computertipp entfernen</translation>
    </message>
    <message>
        <source>Rotate 90</source>
        <translation>Rotieren um 90</translation>
    </message>
    <message>
        <source>Set computer hint &apos;brake&apos;..</source>
        <translation>Computertipp auf »Bremsen« setzen</translation>
    </message>
    <message>
        <source>Insert row..</source>
        <translation type="vanished">Zeile einfügen</translation>
    </message>
    <message>
        <source>Delete row..</source>
        <translation>Zeile löschen</translation>
    </message>
    <message>
        <source>Insert column..</source>
        <translation type="vanished">Spalte einfügen</translation>
    </message>
    <message>
        <source>Delete column..</source>
        <translation>Spalte löschen</translation>
    </message>
    <message>
        <source>Exclude from minimap</source>
        <translation>Aus der Minikarte ausschließen</translation>
    </message>
    <message>
        <source>Insert row before..</source>
        <translation>Zeile davor einfügen</translation>
    </message>
    <message>
        <source>Insert row after..</source>
        <translation>Zeile dahinter einfügen</translation>
    </message>
    <message>
        <source>Insert column before..</source>
        <translation>Spalte davor einfügen</translation>
    </message>
    <message>
        <source>Insert column after..</source>
        <translation>Spalte dahinter einfügen</translation>
    </message>
    <message>
        <source>Force stationary</source>
        <translation>Stationär machen</translation>
    </message>
</context>
<context>
    <name>RotateDialog</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Angle in degrees:</source>
        <translation>Winkel in Grad:</translation>
    </message>
    <message>
        <source>Rotate Object</source>
        <translation>Objekt rotieren</translation>
    </message>
</context>
<context>
    <name>TargetNodeSizeDlg</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Breite:</translation>
    </message>
    <message>
        <source>Set target node size</source>
        <translation>Zielknotengröße setzen</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Höhe:</translation>
    </message>
</context>
<context>
    <name>TrackPropertiesDialog</name>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Set track properties</source>
        <translation>Streckeneigenschaften setzen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Index:</source>
        <translation>Index:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation></translation>
    </message>
    <message>
        <source>User track:</source>
        <translation>Benutzerstrecke:</translation>
    </message>
</context>
</TS>
